==> aroundme_0_5_0.zip: aroundme_0_5_0/aroundme/template/barnraiser_01/default_pre_login.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<!DOCTYPE html
PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">

<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title><?php echo $lang['txt_page_title'];?></title>
<style type="text/css">
<!--
@import url(<?php echo $templatePath;?>aroundme.css);

-->
</style>
<!--[if IE]>
<style type="text/css">
@import url(<?php echo $templatePath;?>aroundme-IE.css);
</style>
<![endif]-->


<script language="JavaScript" src="js/functions.js" type="text/javascript"></script>

<link rel="SHORTCUT ICON" href="<?php echo $templatePath;?>img/favicon.ico" />

</head>

<body bgcolor="#ffffff">

<?php
if (isset($lang['arr_lang_name']) && count($lang['arr_lang_name']) > 1) {
$end_num = 1;
?>
<table width="760" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td valign="top" align="right">
			<div id="breadcrumb">
			<?php
			foreach($lang['arr_lang_name'] as $key => $i):
			if (isset($language_id) && $language_id == $key) {
			?>
			<?php echo $i;?>
			<?php
			}
			else {
			?>
			<a href="<?php echo $current_filename;?>?language_id=<?php echo $key;?>"><?php echo $i;?></a>
			<?php
			}
			?>

			<?php
			if ($end_num < count($lang['arr_lang_name'])) {
				echo "&nbsp;&nbsp;&#47;&nbsp;&nbsp;";
				$end_num++;
			}
			endforeach;
			?>
			<br />
			</div>
		</td>
	</tr>
</table>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" /><br />
<?php }?>

<table width="760" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td>
			<a href="index.php"><img src="<?php echo $templatePath;?>img/aroundme.png" hspace="3" vspace="6" width="180" height="56" alt="" border="0" /></a><br />
		</td>
	</tr>
</table>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="20" /><br />




<?php
if (isset($log)) {
?>
<div id="box_error">
	<?php
	foreach($log as $key => $i):
		if (isset($i[0])) {
			unset($error);
			if (isset($error_handling) && $error_handling>0 && isset($i[1])) {
				$error = $lang['arr_error'][$i[0]] . ": " . $i[2] . "<br />";
			}
			elseif (empty($i[1])) {
				$error = $lang['arr_error'][$i[0]] . "<br />";
			}
		}
		
		if (isset($error)) {
			echo "<p>" . $error . "</p>";
		}
	endforeach;
	?>
</div>
<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
<?php }?>

<table width="760" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td>
			<div id="content">
				<?php echo $content;?>
			</div>
		</td>
	</tr>
	<tr>
		<td align="center" id="breadcrumb">
		<?php echo $lang['copyright'];?><br />
		</td>
	</tr>
</table>

</body>
</html>

==> aroundme_0_5_3.zip: aroundme_0_5_3/aroundme/template/barnraiser_01/default_pre_login.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<!DOCTYPE html
PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">

<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title><?php echo $lang['txt_page_title'];?></title>
<style type="text/css">
<!--
@import url(<?php echo $templatePath;?>aroundme.css);

-->
</style>
<!--[if IE]>
<style type="text/css">
@import url(<?php echo $templatePath;?>aroundme-IE.css);
</style>
<![endif]-->


<script language="JavaScript" src="js/functions.js" type="text/javascript"></script>

<link rel="SHORTCUT ICON" href="<?php echo $templatePath;?>img/favicon.ico" />

</head>

<body bgcolor="#ffffff">
<div id="page">

<?php
if (isset($lang['arr_lang_name']) && count($lang['arr_lang_name']) > 1) {
$end_num = 1;
?>
<table width="760" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td valign="top" align="right">
			<div id="breadcrumb">
			<?php
			foreach($lang['arr_lang_name'] as $key => $i):
			if (isset($language_id) && $language_id == $key) {
			?>
			<?php echo $i;?>
			<?php
			}
			else {
			?>
			<a href="<?php echo $current_filename;?>?language_id=<?php echo $key;?>"><?php echo $i;?></a>
			<?php
			}
			?>

			<?php
			if ($end_num < count($lang['arr_lang_name'])) {
				echo "&nbsp;&nbsp;&#47;&nbsp;&nbsp;";
				$end_num++;
			}
			endforeach;
			?>
			<br />
			</div>
		</td>
	</tr>
</table>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" /><br />
<?php }?>

<table width="760" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td>
			<a href="index.php"><img src="<?php echo $templatePath;?>img/aroundme.png" hspace="3" vspace="6" width="180" height="56" alt="" border="0" /></a><br />
		</td>
	</tr>
</table>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="20" /><br />




<?php
if (isset($log)) {
?>
<div id="box_error">
	<?php
	foreach($log as $key => $i):
		if (isset($i[0])) {
			unset($error);
			if (isset($error_handling) && $error_handling>0 && isset($i[1])) {
				$error = $lang['arr_error'][$i[0]] . ": " . $i[2] . "<br />";
			}
			elseif (empty($i[1])) {
				$error = $lang['arr_error'][$i[0]] . "<br />";
			}
		}
		
		if (isset($error)) {
			echo "<p>" . $error . "</p>";
		}
	endforeach;
	?>
</div>
<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
<?php }?>


<div id="content">
<?php echo $content;?>
</div>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="18" alt="" border="0" /><br />

<div id="breadcrumb" align="center">
	<?php echo $lang['copyright'];?><br />
</div>


</div>
</body>
</html>
